@@ -364,6 +364,71 @@ class DollarList:
         """
         self.items.append(DollarListWriter().create_dollar_item(item))
 
+    @staticmethod
+    def from_string(string):
+        """
+        Create a DollarList from a string
+        String input is in the format of:
+        $lb(<item1>,<item2>,<item3>,<item4>...)
+        where item can be:
+        - a string
+        - a number
+        - a list
+        A list can be nested
+        Parse the string item by item. Move in the string until the next ',' or ')'
+        """
+        if string[0:3] != '$lb':
+            raise DollarListException("Invalid string format")
+        string = string[3:]
+        if string[0] != '(':
+            raise DollarListException("Invalid string format")
+        string = string[1:]
+        response = DollarList()
+        while string[0] != ')':
+            if string[0] == '$':
+                # list
+                # count the number of '$lb(' and ')' to find the end of the list
+                # and create a new string
+                # then call DollarList.from_string
+                # remove the new string from the original string
+                # and continue
+                count = 0
+                for i,value in enumerate(string):
+                    if string[i:i+3] == '$lb':
+                        count += 1
+                    elif value == ')':
+                        count -= 1
+                    if count == 0:
+                        item = DollarList.from_string(string[0:i+1])
+                        response.append(item)
+                        string = string[i+1:]
+
+            elif string[0] == '"':
+                # string
+                end = string.find('"',1)
+                response.append(string[1:end])
+                string = string[end+1:]
+            elif string[0] == '-':
+                # negative int
+                end = string.find(',',1)
+                if end == -1:
+                    end = string.find(')')
+                response.append(int(string[0:end]))
+                string = string[end:]
+            elif string[0].isdigit():
+                # positive int
+                end = string.find(',',1)
+                if end == -1:
+                    end = string.find(')')
+                response.append(int(string[0:end]))
+                string = string[end:]
+            else:
+                raise DollarListException("Invalid string format")
+            if string[0] == ',':
+                string = string[1:]
+        return response
+
+
     def to_bytes(self):
         """
         Convert a DollarList to bytes
@@ -380,12 +445,14 @@ class DollarList:
         For each item in the list, create a DollarItem
         """
         dollar_list = DollarList()
-        dlw = DollarListWriter()
-        if len(python_list) == 0 or python_list is None:
-            dollar_list.items.append(dlw.create_dollar_item(None))
+        if isinstance(python_list, list):
+            if len(python_list) > 0:
+                for item in python_list:
+                    dollar_list.append(item)
+            else:
+                dollar_list.append(None)
         else:
-            for item in python_list:
-                dollar_list.items.append(dlw.create_dollar_item(item))
+            raise DollarListException("Invalid input type")
         return dollar_list
 
     # add to the dataclass a new constructor from_bytes
